Ricecooker API reference
========================
The detailed information for content developers (chef authors) is presented here:

.. toctree::
   :maxdepth: 2

   nodes
   files
   htmlapps
   exercises
   languages
   chefops


Code examples
-------------

  - See the `examples directory on GitHub <https://github.com/learningequality/ricecooker/tree/master/examples>`__
    full code examples.
  - See the `examples page <examples/index.html>`__ for literate code examples
    that explain how to do specific tasks (find language codes, download subtitles,
    and exercises questions, etc). These examples are available as runnable
    Jupyter notebooks so you can try things out interactively and learn.
  - See the `Cheffing techniques doc <https://docs.google.com/document/d/18Gwip2a1nzjeFT8PT6hQpVeu9DAhmolCRNbrohPSxPM/edit#>`__
    which provides links to tips and code examples for handling various special cases and content sources.
